==> nmh_1.7.1.orig.tar.gz: nmh-1.7.1/sbr/icalparse.h <==
/* A Bison parser, made by GNU Bison 3.0.4.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_YY_SBR_ICALPARSE_H_INCLUDED
# define YY_YY_SBR_ICALPARSE_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token type.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    ICAL_NAME = 258,
    ICAL_COLON = 259,
    ICAL_VALUE = 260,
    ICAL_CRLF = 261,
    ICAL_SEMICOLON = 262,
    ICAL_PARAM_NAME = 263,
    ICAL_EQUAL = 264,
    ICAL_PARAM_VALUE = 265,
    ICAL_COMMA = 266
  };
#endif
/* Tokens.  */
#define ICAL_NAME 258
#define ICAL_COLON 259
#define ICAL_VALUE 260
#define ICAL_CRLF 261
#define ICAL_SEMICOLON 262
#define ICAL_PARAM_NAME 263
#define ICAL_EQUAL 264
#define ICAL_PARAM_VALUE 265
#define ICAL_COMMA 266

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef int YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE yylval;

int yyparse (void);

#endif /* !YY_YY_SBR_ICALPARSE_H_INCLUDED  */

==> nmh_1.8.orig.tar.gz: nmh-1.8/sbr/icalparse.h <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_YY_SBR_ICALPARSE_H_INCLUDED
# define YY_YY_SBR_ICALPARSE_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    ICAL_NAME = 258,               /* ICAL_NAME  */
    ICAL_COLON = 259,              /* ICAL_COLON  */
    ICAL_VALUE = 260,              /* ICAL_VALUE  */
    ICAL_CRLF = 261,               /* ICAL_CRLF  */
    ICAL_SEMICOLON = 262,          /* ICAL_SEMICOLON  */
    ICAL_PARAM_NAME = 263,         /* ICAL_PARAM_NAME  */
    ICAL_EQUAL = 264,              /* ICAL_EQUAL  */
    ICAL_PARAM_VALUE = 265,        /* ICAL_PARAM_VALUE  */
    ICAL_COMMA = 266               /* ICAL_COMMA  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif
/* Token kinds.  */
#define YYEMPTY -2
#define YYEOF 0
#define YYerror 256
#define YYUNDEF 257
#define ICAL_NAME 258
#define ICAL_COLON 259
#define ICAL_VALUE 260
#define ICAL_CRLF 261
#define ICAL_SEMICOLON 262
#define ICAL_PARAM_NAME 263
#define ICAL_EQUAL 264
#define ICAL_PARAM_VALUE 265
#define ICAL_COMMA 266

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef int YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE yylval;


int yyparse (void);


#endif /* !YY_YY_SBR_ICALPARSE_H_INCLUDED  */
